#!/usr/bin/env python
# -*- coding: utf-8 -*-

import colorsys
from PIL import Image
import optparse

def get_dominant_color(image):
    """
    Find a PIL image's dominant color, returning an (r, g, b) tuple.
    """
    allcolor = dict()
    result = list()
    image = image.convert('RGBA')
    
    # Shrink the image, so we don't spend too long analysing color
    # frequencies. We're not interpolating so should be quick.
    image.thumbnail((100, 100))
    
    max_score = None
    dominant_color = None
    
    for count, (r, g, b, a) in image.getcolors(image.size[0] * image.size[1]):
        # Skip 100% transparent pixels
        if a == 0:
            continue
        
        # Get color saturation, 0-1
        saturation = colorsys.rgb_to_hsv(r / 255.0, g / 255.0, b / 255.0)[1]
        
        # Calculate luminance - integer YUV conversion from
        # http://en.wikipedia.org/wiki/YUV
        y = min(abs(r * 2104 + g * 4130 + b * 802 + 4096 + 131072) >> 13, 235)
        
        # Rescale luminance from 16-235 to 0-1
        y = (y - 16.0) / (235 - 16)
        
        # Ignore the brightest colors
        if y > 0.9:
            continue
        
        # Calculate the score, preferring highly saturated colors.
        # Add 0.1 to the saturation so we don't completely ignore grayscale
        # colors by multiplying the count by zero, but still give them a low
        # weight.
        score = (saturation + 0.1) * count
        
	'''
        if score > max_score:
            max_score = score
            dominant_color = (r, g, b)
	'''
	allcolor[score]=(r,g,b)

    keys = allcolor.keys()
    keys.sort(None,None,True)
    index = 0
    for k in keys:
	result.append(allcolor[k])
        index += 1
        if index>=6:
		break
    return result

def main():
    usage = 'usage: %prog -f filepath'
    parser = optparse.OptionParser(usage)
    parser.add_option('-f', '--filepath', dest='filepath', help='-f filepath', type='string')
    (options, args) = parser.parse_args()
    if options.filepath == None:
        parser.error('must has -f option!')
    try:
	print options.filepath
        img = Image.open(options.filepath)
    except:
        print("can not open the file")
        return 
    
    for one in get_dominant_color(img):
    	print '#%02x%02x%02x' % one

if __name__ == '__main__':
    main()
